Introduction
============

The ``debops.java`` Ansible role installs the default Java OpenJRE headless
packages for current OS release. It can also be used to install other Java or
OpenJDK/OpenJRE versions.

Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.0.0``. To install it, run:

.. code-block:: console

   user@host:~$ ansible-galaxy install debops.java

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
